==> uni_pytorch-1.10.0-py3-none-any.whl: uni/pytorch/onnx_parser/nnir_node_factory/transpose_factory.py <==
# -------------------------------------------------------------------------------
# (c) Copyright 2023 Sony Semiconductor Israel, Ltd. All rights reserved.
#
#      This software, in source or object form (the "Software"), is the
#      property of Sony Semiconductor Israel Ltd. (the "Company") and/or its
#      licensors, which have all right, title and interest therein, You
#      may use the Software only in accordance with the terms of written
#      license agreement between you and the Company (the "License").
#      Except as expressly stated in the License, the Company grants no
#      licenses by implication, estoppel, or otherwise. If you are not
#      aware of or do not agree to the License terms, you may not use,
#      copy or modify the Software. You may use the source code of the
#      Software only for your internal purposes and may not distribute the
#      source code of the Software, any part thereof, or any derivative work
#      thereof, to any third party, except pursuant to the Company's prior
#      written consent.
#      The Software is the confidential information of the Company.
# -------------------------------------------------------------------------------
"""
Created on 1/5/23

@author: irenab
"""
from uni.common.core.nnir_graph.nnir_nodes import Transpose
from uni.common.core.node_history import NodeHistory
from .base_factory import OnnxFactoryBase, validate_onnx


class OnnxTransposeToNnirNode(OnnxFactoryBase):
    """ https://github.com/onnx/onnx/blob/main/docs/Operators.md#Transpose """

    @classmethod
    @validate_onnx(num_inputs=1, num_outputs=1, attrs=[], optional_attrs=['perm'])
    def from_onnx(cls, onnx_node, graph_ctx=None) -> Transpose:
        if onnx_node.has_attr('perm'):
            axes = onnx_node.get_attr('perm')
        else:
            # By default, onnx reverses the axes
            ndims = len(graph_ctx.get_in_shapes()[0])
            axes = tuple(reversed(range(ndims)))
        history = NodeHistory(cls.onnx_op_info(onnx_node))
        return Transpose(name=onnx_node.name, axes=tuple(axes), history=history)

==> uni_pytorch-3.16.1-py3-none-any.whl: uni/pytorch/onnx_parser/nnir_node_factory/transpose_factory.py <==
# -------------------------------------------------------------------------------
# (c) Copyright 2023 Sony Semiconductor Israel, Ltd. All rights reserved.
#
#      This software, in source or object form (the "Software"), is the
#      property of Sony Semiconductor Israel Ltd. (the "Company") and/or its
#      licensors, which have all right, title and interest therein, You
#      may use the Software only in accordance with the terms of written
#      license agreement between you and the Company (the "License").
#      Except as expressly stated in the License, the Company grants no
#      licenses by implication, estoppel, or otherwise. If you are not
#      aware of or do not agree to the License terms, you may not use,
#      copy or modify the Software. You may use the source code of the
#      Software only for your internal purposes and may not distribute the
#      source code of the Software, any part thereof, or any derivative work
#      thereof, to any third party, except pursuant to the Company's prior
#      written consent.
#      The Software is the confidential information of the Company.
# -------------------------------------------------------------------------------
"""
Created on 1/5/23

@author: irenab
"""
from uni.common.core.nnir_graph.nnir_nodes import Transpose
from uni.common.core.node_history import NodeHistory
from uni.pytorch.onnx_parser.nnir_node_factory.base_factory import OnnxFactoryBase, validate_onnx


class OnnxTransposeToNnirNode(OnnxFactoryBase):
    """ https://github.com/onnx/onnx/blob/main/docs/Operators.md#Transpose """

    @classmethod
    @validate_onnx(num_inputs=1, num_outputs=1, attrs=[], optional_attrs=['perm'])
    def from_onnx(cls, onnx_node, graph_ctx=None) -> Transpose:
        if onnx_node.has_attr('perm'):
            axes = onnx_node.get_attr('perm')
        else:
            # By default, onnx reverses the axes
            ndims = len(graph_ctx.get_in_shapes()[0])
            axes = tuple(reversed(range(ndims)))
        history = NodeHistory(cls.onnx_op_info(onnx_node))
        return Transpose(name=onnx_node.name, axes=tuple(axes), history=history)
